@@ -30,6 +30,10 @@ try:
     import prometheus_client
 except ImportError:
     prometheus_client = None
+try:
+    import influxdb
+except ImportError:
+    influxdb = None
 
 
 from openstack import version as openstack_version
@@ -233,6 +237,7 @@ class CloudRegion(object):
                  cache_path=None, cache_class='dogpile.cache.null',
                  cache_arguments=None, password_callback=None,
                  statsd_host=None, statsd_port=None, statsd_prefix=None,
+                 influxdb_config=None,
                  collector_registry=None):
         self._name = name
         self.config = _util.normalize_keys(config)
@@ -261,6 +266,8 @@ class CloudRegion(object):
         self._statsd_port = statsd_port
         self._statsd_prefix = statsd_prefix
         self._statsd_client = None
+        self._influxdb_config = influxdb_config
+        self._influxdb_client = None
         self._collector_registry = collector_registry
 
         self._service_type_manager = os_service_types.ServiceTypes()
@@ -314,6 +321,10 @@ class CloudRegion(object):
         else:
             return 'unknown'
 
+    def set_service_value(self, key, service_type, value):
+        key = _make_key(key, service_type)
+        self.config[key] = value
+
     def set_session_constructor(self, session_constructor):
         """Sets the Session constructor."""
         self._session_constructor = session_constructor
@@ -466,13 +477,34 @@ class CloudRegion(object):
             value = auth.get('auth_url')
         return value
 
-    def get_endpoint_from_catalog(self, service_type):
+    def get_endpoint_from_catalog(
+            self, service_type, interface=None, region_name=None):
+        """Return the endpoint for a given service as found in the catalog.
+
+        For values respecting endpoint overrides, see
+        :meth:`~openstack.connection.Connection.endpoint_for`
+
+        :param service_type: Service Type of the endpoint to search for.
+        :param interface:
+            Interface of the endpoint to search for. Optional, defaults to
+            the configured value for interface for this Connection.
+        :param region_name:
+            Region Name of the endpoint to search for. Optional, defaults to
+            the configured value for region_name for this Connection.
+
+        :returns: The endpoint of the service, or None if not found.
+        """
+        interface = interface or self.get_interface(service_type)
+        region_name = region_name or self.get_region_name(service_type)
         session = self.get_session()
-        return session.auth.get_endpoint(
-            session,
-            service_type=service_type,
-            region_name=self.get_region_name(service_type),
-            interface=self.get_interface(service_type))
+        catalog = session.auth.get_access(session).service_catalog
+        try:
+            return catalog.url_for(
+                service_type=service_type,
+                interface=interface,
+                region_name=region_name)
+        except keystoneauth1.exceptions.catalog.EndpointNotFound:
+            return None
 
     def get_connect_retries(self, service_type):
         return self._get_config('connect_retries', service_type,
@@ -617,7 +649,7 @@ class CloudRegion(object):
             self.get_interface(service_type), {})
         return interface_versions.get(service_type, [])
 
-    def _get_hardcoded_endpoint(self, service_type, constructor):
+    def _get_endpoint_from_catalog(self, service_type, constructor):
         adapter = constructor(
             session=self.get_session(),
             service_type=self.get_service_type(service_type),
@@ -625,7 +657,11 @@ class CloudRegion(object):
             interface=self.get_interface(service_type),
             region_name=self.get_region_name(service_type),
         )
-        endpoint = adapter.get_endpoint()
+        return adapter.get_endpoint()
+
+    def _get_hardcoded_endpoint(self, service_type, constructor):
+        endpoint = self._get_endpoint_from_catalog(
+            service_type, constructor)
         if not endpoint.rstrip().rsplit('/')[-1] == 'v2.0':
             if not endpoint.endswith('/'):
                 endpoint += '/'
@@ -661,6 +697,8 @@ class CloudRegion(object):
         kwargs.setdefault('prometheus_counter', self.get_prometheus_counter())
         kwargs.setdefault(
             'prometheus_histogram', self.get_prometheus_histogram())
+        kwargs.setdefault('influxdb_config', self._influxdb_config)
+        kwargs.setdefault('influxdb_client', self.get_influxdb_client())
         endpoint_override = self.get_endpoint(service_type)
         version = version_request.version
         min_api_version = (
@@ -936,7 +974,11 @@ class CloudRegion(object):
         if self._statsd_port:
             statsd_args['port'] = self._statsd_port
         if statsd_args:
-            return statsd.StatsClient(**statsd_args)
+            try:
+                return statsd.StatsClient(**statsd_args)
+            except Exception:
+                self.log.warning('Cannot establish connection to statsd')
+                return None
         else:
             return None
 
@@ -1003,3 +1045,29 @@ class CloudRegion(object):
         service_type = service_type.lower().replace('-', '_')
         d_key = _make_key('disabled_reason', service_type)
         return self.config.get(d_key)
+
+    def get_influxdb_client(self):
+        influx_args = {}
+        if not self._influxdb_config:
+            return None
+        use_udp = bool(self._influxdb_config.get('use_udp', False))
+        port = self._influxdb_config.get('port')
+        if use_udp:
+            influx_args['use_udp'] = True
+        if 'port' in self._influxdb_config:
+            if use_udp:
+                influx_args['udp_port'] = port
+            else:
+                influx_args['port'] = port
+        for key in ['host', 'username', 'password', 'database', 'timeout']:
+            if key in self._influxdb_config:
+                influx_args[key] = self._influxdb_config[key]
+        if influxdb and influx_args:
+            try:
+                return influxdb.InfluxDBClient(**influx_args)
+            except Exception:
+                self.log.warning('Cannot establish connection to InfluxDB')
+        else:
+            self.log.warning('InfluxDB configuration is present, '
+                             'but no client library is found.')
+        return None
